@@ -1,10 +1,9 @@
-from enum import auto
 from bxcommon.models.serializable_flag import SerializableFlag
 
 
 class EntityType(SerializableFlag):
-    TRANSACTION = auto()
-    BLOCK = auto()
+    TRANSACTION = 1
+    BLOCK = 2
 
     def __str__(self):
         return str(self.name).lower()
