@@ -8,6 +8,7 @@ from bxcommon.utils.object_hash import Sha256Hash
 
 from bxgateway.messages.eth.protocol.new_block_eth_protocol_message import NewBlockEthProtocolMessage
 from bxgateway.services.abstract_block_cleanup_service import AbstractBlockCleanupService
+from bxgateway.services.eth.eth_block_queuing_service import EthBlockQueuingService
 
 from bxutils import logging
 from bxutils.logging.log_record_type import LogRecordType
@@ -48,11 +49,9 @@ class AbstractEthBlockCleanupService(AbstractBlockCleanupService):
 
     def clean_block_transactions_from_block_queue(
         self,
-        block_hash: Sha256Hash
+        block_hash: Sha256Hash,
+        block_queuing_service: EthBlockQueuingService
     ) -> None:
-        block_queuing_service = typing.cast(
-            "bxgateway.services.eth.eth_block_queuing_service.EthBlockQueuingService", self.node.block_queuing_service
-        )
         try:
             block_body = block_queuing_service.get_block_body_from_message(block_hash)
             assert block_body is not None
@@ -80,10 +79,11 @@ class AbstractEthBlockCleanupService(AbstractBlockCleanupService):
         pass
 
     def _request_block(self, block_hash: Sha256Hash) -> None:
-        node_conn = self.node.node_conn
-        assert node_conn is not None
-        connection_protocol = \
-            typing.cast("bxgateway.connections.eth.eth_node_connection_protocol.EthNodeConnectionProtocol",
-                        node_conn.connection_protocol)
+        node_conn = typing.cast("bxgateway.connections.eth.eth_node_connection.EthNodeConnection",
+                                self.node.get_any_active_blockchain_connection())
+        if node_conn is None:
+            logger.debug("Request for block '{}' failed. No connection to node.", repr(block_hash))
+            return
+        connection_protocol = node_conn.connection_protocol
         connection_protocol.request_block_body([block_hash])
         logger.trace("Block cleanup request for {}", block_hash)
